﻿using System.Collections.ObjectModel;
using AsReaderA24DMAUIDemo.Platforms.Droid;

namespace AsReaderA24DMAUIDemo;

public partial class MainPage : ContentPage
{
    private AsReaderA24DManager formManager;
    private AsReaderA24DDelegate asReaderA24DDelegate;
    private ObservableCollection<DataModel> dataModelList = new ObservableCollection<DataModel>();
    private ObservableCollection<DataModel> DataModel { get { return dataModelList; } }
    private Dictionary<string, DataModel> dataDic = new Dictionary<string, DataModel>();
    private int count;
    private string barcodeHexString = "";

    public MainPage()
    {
        InitializeComponent();
        count = 0;
        formManager = AsReaderA24DManager.sharedInstance();
        asReaderA24DDelegate = AsReaderA24DDelegate.sharedInstance();
    }
    protected override void OnAppearing()
    {
        base.OnAppearing();
        asReaderA24DDelegate.OnConnect = (bool connect) =>
        {
            OnConnect(connect);
        };
        asReaderA24DDelegate.OnBatteryStateReceived = (int battery) =>
        {
            OnBatteryStateReceived(battery);
        };
        asReaderA24DDelegate.OnReceivedBarcodeDecodeData = (string decodeData, Dictionary<string, string> parameter) =>
        {
            OnReceivedBarcodeDecodeData(decodeData, parameter);
        };
        asReaderA24DDelegate.OnReceivedBarcodeDecodeByteData = (byte[] decodeData) =>
        {
            OnReceivedBarcodeDecodeByteData(decodeData);
        };
        if (formManager.GetAsReaderStatus())
        {
            SetUI(true);
        }
        else
        {
            SetUI(false);
        }
        ListView.ItemsSource = dataModelList;
    }
    protected override void OnDisappearing()
    {
        base.OnDisappearing();
        asReaderA24DDelegate.OnConnect = null;
        asReaderA24DDelegate.OnBatteryStateReceived = null;
        asReaderA24DDelegate.OnReceivedBarcodeDecodeData = null;
        asReaderA24DDelegate.OnReceivedBarcodeDecodeByteData = null;
    }
    private async void OnSettingsClicked(object sender, EventArgs e)
    {
        await Navigation.PushAsync(new MorePage());
    }
    private void OnScanClicked(object sender, EventArgs e)
    {
        formManager.StartDecode();
    }
    private void OnClearClicked(object sender, EventArgs e)
    {
        dataModelList.Clear();
        dataDic.Clear();
        barcodeHexString = "";
        count = 0;
        TagLabel.Text = count.ToString() + " Barcode";
    }
    private void OnStopClicked(object sender, EventArgs e)
    {
        formManager.StopDecode();
    }
    private void OnListViewItemSelected(object sender, SelectedItemChangedEventArgs args)
    {
        (sender as ListView).SelectedItem = null;
        if (args.SelectedItem != null)
        {
            DataModel dataModel = args.SelectedItem as DataModel;
            BarcodePage barcodePage = new BarcodePage();
            barcodePage.codeID = dataModel.Type;
            barcodePage.barcode = dataModel.Barcode;
            barcodePage.bytes = dataModel.Data;
            Navigation.PushAsync(barcodePage);
        }
    }
    private void OnConnect(bool connect)
    {
        MainThread.BeginInvokeOnMainThread(() =>
        {
            SetUI(connect);
        });
    }
    private void OnBatteryStateReceived(int battery)
    {
        MainThread.BeginInvokeOnMainThread(() =>
        {
            BatteryLabel.Text = battery.ToString() + "%";
        });
    }
    private void OnReceivedBarcodeDecodeData(string decodeData, Dictionary<string, string> parameter)
    {
        string symbol = "";
        if (parameter.ContainsKey("Key_ParameterSymbol"))
        {
            symbol = parameter["Key_ParameterSymbol"];
        }
        DataModel dataChanged;
        if (dataDic.ContainsKey(symbol + decodeData))
        {
            dataChanged = dataDic[symbol + decodeData];
            dataChanged.Count++;
            dataDic[symbol + decodeData] = dataChanged;
        }
        else
        {
            dataChanged = new DataModel(symbol, decodeData, barcodeHexString, 1, ">");
            dataDic.Add(symbol + decodeData, dataChanged);
            dataModelList.Add(dataChanged);
            count++;
        }
        MainThread.BeginInvokeOnMainThread(() =>
        {
            ListView.ItemsSource = null;
            ListView.ItemsSource = dataModelList;
            TagLabel.Text = count.ToString() + " Barcode";
        });
    }
    private void OnReceivedBarcodeDecodeByteData(byte[] decodeData)
    {
        MainThread.BeginInvokeOnMainThread(() =>
        {
            barcodeHexString = "";
            foreach (byte decodeDatum in decodeData)
            {
                barcodeHexString += (decodeDatum & 0xFF).ToString("X2") + " ";
            }
        });
    }
    private void SetUI(bool status)
    {
        if (status)
        {
            StatusLabel.Text = "Connected";
            VersionLabel.Text = "APP Version:" + formManager.GetAPPVersion();
            StartScanButton.IsEnabled = true;
            ClearButton.IsEnabled = true;
            StopButton.IsEnabled = true;
            StartScanButton.BackgroundColor = Color.FromRgba(81, 43, 212, 255);
            ClearButton.BackgroundColor = Color.FromRgba(81, 43, 212, 255);
            StopButton.BackgroundColor = Color.FromRgba(81, 43, 212, 255);
            More.IsEnabled = true;
            ListView.IsEnabled = true;
            formManager.SetDeviceDefault();
        }
        else
        {
            StatusLabel.Text = "Disconnected";
            StartScanButton.IsEnabled = false;
            ClearButton.IsEnabled = false;
            StopButton.IsEnabled = false;
            StartScanButton.BackgroundColor = Colors.LightGray;
            ClearButton.BackgroundColor = Colors.LightGray;
            StopButton.BackgroundColor = Colors.LightGray;
            More.IsEnabled = false;
            ListView.IsEnabled = false;
            BatteryLabel.Text = "Unknown";
        }
    }
}


